Module angle
siege_
math
0.5.1
Module angle
Module Items
Structs
In crate siege_
math
siege_math
Module
angle
Structs

Angle
A type for representing an angle, without needing to remember if it is denominated in Radians, Degrees, or otherwise.